unit FieldValueForm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Mask, StdCtrls, IDGNumberEdit, ComCtrls, ExtCtrls, Buttons, CustomQueryDesigner,
  CustomQueryDesignerTypes, Db;

type
  TFFieldValue = class(TForm)
    Panel1: TPanel;
    BitBtn1: TBitBtn;
    BitBtn2: TBitBtn;
    Notebook1: TNotebook;
    DateFieldName1: TLabel;
    DateFieldName2: TLabel;
    DateOperator1: TComboBox;
    DateValue1: TDateTimePicker;
    DateBoolBetweenFields: TComboBox;
    DateOperator2: TComboBox;
    DateValue2: TDateTimePicker;
    IntegerFieldName1: TLabel;
    IntegerBoolBetWeenFields: TComboBox;
    IntegerFieldName2: TLabel;
    IntegerOperator2: TComboBox;
    IntegerOperator1: TComboBox;
    StringFieldName1: TLabel;
    StringBoolBetWeenFields: TComboBox;
    StringFieldName2: TLabel;
    StringOperator2: TComboBox;
    StringOperator1: TComboBox;
    FloatFieldName1: TLabel;
    FloatBoolBetweenFields: TComboBox;
    FloatFieldName2: TLabel;
    FloatOperator2: TComboBox;
    FloatOperator1: TComboBox;
    FloatValue1: TIDGNumberEdit;
    FloatValue2: TIDGNumberEdit;
    StringValue1: TEdit;
    StringValue2: TEdit;
    IntegerValue1: TMaskEdit;
    IntegerValue2: TMaskEdit;
    Panel2: TPanel;
    Shape1: TShape;
    MainLabel: TLabel;
    CBClearValues: TCheckBox;
  private
    { Private declarations }
    fDataType : TFieldType;
  public
    { Public declarations }
    constructor Create( AOwner : TComponent; FieldDisplayName: string; DataType: TFieldType ); reintroduce;
    procedure SetUpOperatorComboBox( Combobox : TCombobox );
    procedure SetUpBoolComboBox( Combobox : TCombobox );
    procedure SetUpValues( StrLength: Integer;
                           MainBool,
                           BoolBetweenFields: TFieldBoolOperators;
                           FieldLowValue,
                           FieldHighValue: TFieldValueExpression);

    procedure NewValues( var MainBool,
                             BoolBetweenFields: TFieldBoolOperators;
                         var FieldLowValue,
                             FieldHighValue: TFieldValueExpression;
                         var ClearValues : boolean);

  end;

//const
  (* Form width depending by type*)

var
  FFieldValue: TFFieldValue;

implementation

{$R *.DFM}
constructor TFFieldValue.Create( AOwner : TComponent; FieldDisplayName: string; DataType: TFieldType );
begin
  inherited Create(AOwner);
  fDataType := DataType;

  MainLabel.Caption := Format(MainLabel.Caption,[FieldDisplayName]);

  case fDataType of
    ftSmallInt,
    ftInteger,
    ftLargeInt : begin
      NoteBook1.ActivePage := 'AsInteger';

      SetUpBoolComboBox(IntegerboolBetweenFields);

      SetUpOperatorComboBox(IntegerOperator1);
      SetUpOperatorComboBox(IntegerOperator2);

      IntegerFieldName1.Caption := FieldDisplayName;
      IntegerFieldName2.Caption := FieldDisplayName;

    end;

    ftFloat : begin
      NoteBook1.ActivePage := 'AsFloat';

      SetUpBoolComboBox(FloatBoolBetweenFields);

      SetUpOperatorComboBox(FloatOperator1);
      SetUpOperatorComboBox(FloatOperator2);

      FloatFieldName1.Caption := FieldDisplayName;
      FloatFieldName2.Caption := FieldDisplayName;
    end;

    ftDate,
    ftTime,
    ftDateTime : begin
      NoteBook1.ActivePage := 'AsDate';

      SetUpBoolComboBox(DateBoolBetweenFields);

      SetUpOperatorComboBox(DateOperator1);
      SetUpOperatorComboBox(DateOperator2);

      DateFieldName1.Caption := FieldDisplayName;
      DateFieldName2.Caption := FieldDisplayName;
    end;

    ftString : begin
      NoteBook1.ActivePage := 'AsString';

      SetUpBoolComboBox(StringBoolBetweenFields);

      SetUpOperatorComboBox(StringOperator1);
      SetUpOperatorComboBox(StringOperator2);

      StringFieldName1.Caption := FieldDisplayName;
      StringFieldName2.Caption := FieldDisplayName;

    end;

  end;

end;


procedure TFFieldValue.SetUpOperatorComboBox( Combobox : TCombobox );
var i,
    ArrayHigh : integer;
begin

  ArrayHigh := High(TOperatorList);

  if fDataType <> ftString then begin
    Dec(ArrayHigh,2);
  end;

  ComboBox.Items.Clear();

  for i:= 0 to ArrayHigh do begin
    ComboBox.Items.Add(TOperatorList[i]);
  end;

end;

procedure TFFieldValue.SetUpBoolComboBox( Combobox : TCombobox );
var i : integer;
begin

  ComboBox.Items.Clear();
  ComboBox.Items.Add('-');
  for i:= 1 to High(TBoolOperators) do begin
    ComboBox.Items.Add(TBoolOperators[i]);
  end;

end;

procedure TFFieldValue.SetUpValues( StrLength: Integer;
                                    MainBool,
                                    BoolBetweenFields: TFieldBoolOperators;
                                    FieldLowValue,
                                    FieldHighValue: TFieldValueExpression);
begin

  case fDataType of

    ftSmallInt,
    ftInteger,
    ftLargeInt : begin

      IntegerboolBetweenFields.ItemIndex := Ord(BoolBetWeenFields);

      if FieldLowValue.HasValue then begin
        IntegerOperator1.ItemIndex := Ord(FieldLowValue.Operator);
        IntegerValue1.Text         := FieldLowValue.ValueAsText;
      end;

      if FieldHighValue.HasValue then begin
        IntegerOperator2.ItemIndex := Ord(FieldHighValue.Operator);
        IntegerValue2.Text         := FieldHighValue.ValueAsText;
      end;

    end;

    ftFloat : begin

      FloatBoolBetweenFields.ItemIndex := Ord(BoolBetWeenFields);

      if FieldLowValue.HasValue then begin
        FloatOperator1.ItemIndex := Ord(FieldLowValue.Operator);
        FloatValue1.Text         := FieldLowValue.ValueAsText;
      end;

      if FieldHighValue.HasValue then begin
        FloatOperator2.ItemIndex := Ord(FieldHighValue.Operator);
        FloatValue2.Text         := FieldHighValue.ValueAsText;
      end;

    end;

    ftDate,
    ftTime,
    ftDateTime : begin

      DateBoolBetweenFields.ItemIndex := Ord(BoolBetWeenFields);

      if FieldLowValue.HasValue then begin
        DateOperator1.ItemIndex := Ord(FieldLowValue.Operator);
        DateValue1.Date         := StrToDatetime(FieldLowValue.ValueAsText);
      end;

      if FieldHighValue.HasValue then begin
        DateOperator2.ItemIndex := Ord(FieldHighValue.Operator);
        DateValue2.Date         := StrToDatetime(FieldHighValue.ValueAsText);
      end;

    end;

    ftString : begin

      StringValue1.MaxLength := strLength;
      StringValue2.MaxLength := strLength;

      StringBoolBetweenFields.ItemIndex := Ord(BoolBetWeenFields);

      if FieldLowValue.HasValue then begin
        StringOperator1.ItemIndex := Ord(FieldLowValue.Operator);
        StringValue1.Text         := FieldLowValue.ValueAsText;
      end;

      if FieldHighValue.HasValue then begin
        StringOperator2.ItemIndex := Ord(FieldHighValue.Operator);
        StringValue2.Text         := FieldHighValue.ValueAsText;
      end;

    end;

  end;

end;

procedure TFFieldValue.NewValues( var MainBool,
                                      BoolBetweenFields: TFieldBoolOperators;
                                  var FieldLowValue,
                                      FieldHighValue: TFieldValueExpression;
                                  var ClearValues : boolean);
begin

  if not CBClearValues.Checked then begin

    case fDataType of

      ftSmallInt,
      ftInteger,
      ftLargeInt : begin

        IntegerboolBetweenFields.ItemIndex := Ord(BoolBetWeenFields);

        FieldLowValue.Operator := TFieldValueOperators(IntegerOperator1.ItemIndex);
        FieldLowValue.ValueAsText := IntegerValue1.Text;

        FieldHighValue.Operator    := TFieldValueOperators(IntegerOperator2.ItemIndex);
        FieldHighValue.ValueAsText := IntegerValue2.Text;

      end;

      ftFloat : begin

        FloatBoolBetweenFields.ItemIndex := Ord(BoolBetWeenFields);

        FieldLowValue.Operator := TFieldValueOperators(FloatOperator1.ItemIndex);
        FieldLowValue.ValueAsText := FloatValue1.Text;

        FieldHighValue.Operator := TFieldValueOperators(FloatOperator2.ItemIndex);
        FieldHighValue.ValueAsText := FloatValue2.Text;

      end;

      ftDate,
      ftTime,
      ftDateTime : begin

        BoolBetWeenFields := TFieldBoolOperators(DateBoolBetweenFields.ItemIndex);

        FieldLowValue.Operator := TFieldValueOperators(DateOperator1.ItemIndex);
        FieldLowValue.ValueAsText := DateToStr(DateValue1.Date);

        FieldHighValue.Operator := TFieldValueOperators(DateOperator2.ItemIndex);
        FieldHighValue.ValueAsText := DateToStr(DateValue2.Date);

      end;

      ftString : begin

        BoolBetWeenFields := TFieldBoolOperators(StringBoolBetweenFields.ItemIndex);

        FieldLowValue.Operator := TFieldValueOperators(StringOperator1.ItemIndex);
        FieldLowValue.ValueAsText := StringValue1.Text;

        FieldHighValue.Operator    := TFieldValueOperators(StringOperator2.ItemIndex);
        FieldHighValue.ValueAsText := StringValue2.Text;

      end;

    end;
  end else begin
    ClearValues := TRUE;
  end;

end;

end.
