unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Db, IBDatabase, Buttons, ComCtrls, IBCustomDataSet, IBQuery,
  CustomQueryDesigner, ShellAPI;


type

  TMainForm = class(TForm)
    TreeView1: TTreeView;
    ListView1: TListView;
    CustomQueryDesigner1: TCustomQueryDesigner;
    BtnResults: TButton;
    BtnClose: TBitBtn;
    IBDatabase1: TIBDatabase;
    Label1: TLabel;
    Path: TEdit;
    BtnConnect: TButton;
    BtnBrowse: TButton;
    OpenDialog1: TOpenDialog;
    IBTransaction1: TIBTransaction;
    ResultQuery: TIBQuery;
    BtnIni: TButton;
    Label2: TLabel;
    ServerAddr: TEdit;
    BtnSave: TBitBtn;
    BtnLoad: TBitBtn;
    procedure BtnBrowseClick(Sender: TObject);
    procedure BtnConnectClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure BtnResultsClick(Sender: TObject);
    procedure CustomQueryDesigner1FieldValueRequired(Sender: TObject;
      Table, FieldName, FieldDisplayName: String; DataType: TFieldType;
      StrLength: Integer; var MainBool,
      BoolBetweenFields: TFieldBoolOperators; var FieldLowValue,
      FieldHighValue: TFieldValueExpression; var ClearValues : boolean);
    procedure BtnIniClick(Sender: TObject);
    procedure BtnLoadClick(Sender: TObject);
    procedure BtnSaveClick(Sender: TObject);

  private
    { Private declarations }
    Queries : TStringList;
    procedure GetQueries( ID : integer; QueryName : string );
  public
    { Public declarations }
  end;

  TIntObj = class(TObject)
  public
    Int : integer;
    constructor Create( Number : integer );
  end;

var
  MainForm: TMainForm;

implementation

uses FieldValueForm, QuerySelectForm, QueryNameForm, QueryResultForm;

{$R *.DFM}

procedure TMainForm.BtnBrowseClick(Sender: TObject);
begin

  if OpenDialog1.Execute() then begin
    Path.Text := OpenDialog1.FileName;
  end;

end;

procedure TMainForm.BtnConnectClick(Sender: TObject);
begin

  if ServerAddr.Text <> '' then begin

    if not IBDataBase1.Connected then begin
      IBDataBase1.DatabaseName:=ServerAddr.Text+':'+Path.Text;
    end;

    IBDataBase1.Connected := not IBDataBase1.Connected;

    if IBDataBase1.Connected then begin
      CustomQueryDesigner1.BuildRelationTree();

      BtnConnect.Caption := 'Disconnect from server';
    end else begin
      BtnConnect.Caption := 'Connect to server';

      ListView1.Items.Clear();
      TreeView1.Items.Clear();

    end;

  end else begin
    MessageDlg('No server specified.',mtError,[mbOk],0);
  end;

end;

procedure TMainForm.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  IBDataBase1.Connected := FALSE;
end;

procedure TMainForm.BtnResultsClick(Sender: TObject);
begin

  if CustomQueryDesigner1.SetUpResultQuery(ResultQuery) then begin
    ResultQuery.Open();
    FQueryResult.ShowModal();
    ResultQuery.Close();
  end else begin
    MessageDlg('Empty Query. Select one or more fields to be in the query.',mtError,[mbOk],0);
  end;

end;

procedure TMainForm.CustomQueryDesigner1FieldValueRequired(Sender: TObject;
  Table, FieldName, FieldDisplayName: String; DataType: TFieldType;
  StrLength: Integer; var MainBool, BoolBetweenFields: TFieldBoolOperators;
  var FieldLowValue, FieldHighValue: TFieldValueExpression;
  var ClearValues : boolean);
begin

  try

    FFieldValue:= TFFieldValue.Create(Self, FieldDisplayName, DataType);
    FFieldValue.SetUpValues( StrLength, MainBool, BoolBetWeenFields, FieldLowValue, FieldHighValue);

    if FFieldValue.ShowModal() = mrOk then begin
      fFieldValue.NewValues( MainBool, BoolBetweenFields,FieldLowValue, FieldHighValue, ClearValues);
    end;

  finally
    fFieldValue.Free();
  end;

end;

procedure TMainForm.BtnIniClick(Sender: TObject);
begin
  ShellExecute(Handle, 'open', pChar(CustomQueryDesigner1.DisplayNameSource),'','',SW_SHOWNORMAL);
end;

procedure TMainForm.GetQueries( ID : integer; QueryName : string );
begin
  Queries.AddObject(QueryName, TIntObj.Create(ID));
end;

procedure TMainForm.BtnLoadClick(Sender: TObject);
var i : integer;
begin
  Queries := TStringList.Create();

  CustomQueryDesigner1.EnumSavedQueries(GetQueries);

  if Queries.Count> 0 then begin

    try

      FSelectQuery := TFSelectQuery.Create( Self );
      FSelectQuery.ListBox1.Items.Assign(Queries);
      FSelectQuery.ListBox1.ItemIndex := 0;

      if FSelectQuery.ShowModal = mrOk then begin
        CustomQueryDesigner1.LoadQuery( (FSelectQuery.ListBox1.Items.Objects[FSelectQuery.ListBox1.ItemIndex] as TIntObj).Int );
      end;

    finally

      if Assigned(FSelectQuery) then begin
        FreeAndNil(FSelectQuery);
      end;

      for i := 0 to Queries.Count-1 do begin
        Queries.Objects[i].Free();
      end;
      Queries.Free();

    end;

  end else begin
    MessageDlg('No saved queries.',mtInformation,[mbOk],0);
  end;

end;

constructor TIntObj.Create( Number : integer );
begin
  Int := Number;
end;

procedure TMainForm.BtnSaveClick(Sender: TObject);
begin

  try
    FQueryName:= TFQueryName.Create(Self);

    if (FQueryName.ShowModal() = mrOk) and (FQueryName.EQueryName.Text <> '') then begin
      CustomQueryDesigner1.SaveQuery( FQueryName.EQueryName.Text );
    end;

  finally
    FQueryName.Free();
  end;


end;

end.
